@@ -1,3 +1,5 @@
+from .client import AioDagpiClient
+
 '''The MIT License (MIT)
 
 Copyright (c) 2020 Raj Sharma
@@ -22,8 +24,6 @@ SOFTWARE.'''
 
 """aiodagpi - An asynchronous python API wrapper for Dagpi : https://dagpi.xyz"""
 
-from .client import aiodagpiclient
-
-__version__ = '0.2.9.1'
+__version__ = '0.3.0'
 __author__ = 'Raj Sharma <yrsharma@icloud.com>'
-__all__ = [aiodagpiclient]
+__all__ = ['aiodagpiclient']
