@@ -20,10 +20,16 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.'''
 
-class aiodagpiexception(Exception):
+
+class AioDagpiException(Exception):
+    """The base AioDagpi exception class
+    """
     pass
 
-class UnknownError(aiodagpiexception):
+
+class UnknownError(AioDagpiException):
+    """When an unknown error occurs
+    """
     def __init__(self, code, error) -> None:
         self.error = error
         self.code = code
@@ -31,31 +37,42 @@ class UnknownError(aiodagpiexception):
     def __str__(self) -> str:
         return f'{self.code} received: {self.error}'
 
-class InvalidToken(aiodagpiexception):
+
+class InvalidToken(AioDagpiException):
+    """When an unkown token is passed
+    """
     def __init__(self, error='Invalid dagpi token passed, check to make sure it is correct.') -> None:
         self.error = error
 
     def __str__(self) -> str:
         return self.error
 
-class InvalidOption(aiodagpiexception):
+
+class InvalidOption(AioDagpiException):
+    """When an invalid option is passed
+    """
     def __init__(self, error='Invalid option selected, check for typos and make sure it exists.') -> None:
         self.error = error
 
     def __str__(self) -> str:
         return self.error
 
-class RateLimited(aiodagpiexception):
+
+class RateLimited(AioDagpiException):
+    """When you are being ratelimited
+    """
     def __init__(self, error='You are being ratelimited for consistent usage, slow it down.') -> None:
         self.error = error
 
     def __str__(self) -> str:
         return self.error
 
-class ServerError(aiodagpiexception):
+
+class ServerError(AioDagpiException):
+    """When there is an internal server error
+    """
     def __init__(self, error='The server raised an error but could not be more specific of its origin. Check back later.') -> None:
         self.error = error
 
     def __str__(self) -> str:
         return self.error
-
